@@ -113,6 +113,11 @@ class d3graph():
         None.
 
         """
+        # Some checks
+        if not hasattr(self, 'edge_properties') or not hasattr(self, 'node_properties'):
+            logger.warning('No graph detected. <return> Hint: "d3.graph(df)"')
+            return None
+
         self.config['figsize'] = figsize
         self.config['network_title'] = title
         # self.config['path'] = '' if filepath is None else filepath
@@ -143,7 +148,7 @@ class d3graph():
             file_location = "file:///" + file_location
         webbrowser.open(file_location, new=2)
 
-    def set_edge_properties(self, edge_distance=None, minmax=[0.5, 15], directed=False, scaler='zscore'):
+    def set_edge_properties(self, edge_distance=None, minmax=[0.5, 15], scaler='zscore', directed=False, marker_start=None, marker_end='arrow', marker_color='#808080'):
         """Edge properties.
 
         Parameters
@@ -155,12 +160,19 @@ class d3graph():
         minmax : tuple(int,int), (default: [0.5, 15])
             Weights are normalized between minimum and maximum
             * [0.5, 15]
-        directed : Bool, (default: False)
-            True: Directed edges (with arrow), False: Undirected edges (without arrow)
         scaler : str, (default: 'zscore')
             Scale the the edge-width in the the range of a minimum and maximum [0.5, 15] using the following scaler:
             'zscore' : Scale values to Z-scores.
             'minmax' : The sklearn scaler will shrink the distribution.
+        directed : Bool, (default: False)
+            True: Edges are shown with an marker (e.g. arrow)
+            False: Edges do not show markers.
+        marker_start : (list of) str, (default: 'arrow')
+            The start of the edge can be one of the following markers:
+            'arrow','square','circle','stub',None or ''
+        marker_end : (list of) str, (default: 'arrow')
+            The end of the edge can be one of the following markers:
+            'arrow','square','circle','stub',None or ''
 
         Returns
         -------
@@ -175,10 +187,22 @@ class d3graph():
         self.config['edge_distance'] = 30 if edge_distance is None else edge_distance
         self.config['minmax'] = minmax
         self.config['edge_scaler'] = scaler
-        # Set the edge properties
-        self.edge_properties = adjmat2dict(self.adjmat, min_weight=0, minmax=self.config['minmax'], scaler=self.config['edge_scaler'])
+        self.config['marker_start']=marker_start
+        self.config['marker_end'] = marker_end
+        self.config['marker_color'] = marker_color
 
-    def set_node_properties(self, label=None, hover=None, color='#000080', size=10, edge_color='#000000', edge_size=1, cmap='Set1', scaler='zscore', minmax=[10, 50]):
+        # Set the edge properties
+        self.edge_properties = adjmat2dict(self.adjmat,
+                                           min_weight=0,
+                                           minmax=self.config['minmax'],
+                                           scaler=self.config['edge_scaler'],
+                                           marker_start=self.config['marker_start'],
+                                           marker_end=self.config['marker_end'],
+                                           marker_color=self.config['marker_color'])
+
+        logger.info('Number of edges: %.0d', len(self.edge_properties.keys()))
+
+    def set_node_properties(self, label=None, tooltip=None, color='#000080', size=10, edge_color='#000000', edge_size=1, cmap='Set1', scaler='zscore', minmax=[10, 50]):
         """Node properties.
 
         Parameters
@@ -187,10 +211,10 @@ class d3graph():
             The text that is shown on the Node.
             If not specified, the label text will be inherited from the adjacency matrix column-names.
             * ['label 1','label 2','label 3', ...]
-        hover : list of names (default: None)
+        tooltip : list of names (default: None)
             The text that is shown when hovering over the Node.
             If not specified, the text will inherited from the label.
-            * ['hover 1','hover 2','hover 3', ...]
+            * ['tooltip 1','tooltip 2','tooltip 3', ...]
         color : list of strings (default: '#000080')
             Color of the node.
             * 'cluster' : Colours are based on the community distance clusters.
@@ -262,18 +286,18 @@ class d3graph():
             label = np.array([''] * nodecount)
         if not (len(label)==nodecount): raise Exception("[label] must be of same length as the number of nodes")
 
-        # Hover text
-        if isinstance(hover, list):
-            hover = np.array(hover).astype(str)
-        elif 'numpy' in str(type(hover)):
+        # tooltip text
+        if isinstance(tooltip, list):
+            tooltip = np.array(tooltip).astype(str)
+        elif 'numpy' in str(type(tooltip)):
             pass
-        elif isinstance(hover, str):
-            hover = np.array([hover] * nodecount)
+        elif isinstance(tooltip, str):
+            tooltip = np.array([tooltip] * nodecount)
         elif label is not None:
-            hover = label
+            tooltip = label
         else:
-            hover = np.array([''] * nodecount)
-        if not (len(hover)==nodecount): raise Exception("[Hover text] must be of same length as the number of nodes")
+            tooltip = np.array([''] * nodecount)
+        if not (len(tooltip)==nodecount): raise Exception("[Tooltip text] must be of same length as the number of nodes")
 
         # Set node color
         if isinstance(color, list) and len(color)==nodecount:
@@ -308,7 +332,7 @@ class d3graph():
             edge_color = np.array(['#000000'] * nodecount)
         else:
             assert 'Node color edge not possible'
-        
+
         # Check correctness of hex colors
         edge_color = _get_hexcolor(edge_color, cmap=self.config['cmap'])
         # Check length edge color with node count. This should match.
@@ -353,13 +377,15 @@ class d3graph():
             self.node_properties[node] = {
                 'name': node,
                 'label': label[i],
-                'hover': hover[i],
+                'tooltip': tooltip[i],
                 'color': color[i].astype(str),
                 'size': size[i],
                 'edge_size': edge_size[i],
                 'edge_color': edge_color[i],
                 'cluster_label': cluster_label[i]}
 
+        logger.info('Number of unique nodes: %.0d', len(self.node_properties.keys()))
+
     # compute clusters
     def get_cluster_color(self, node_names=None):
         """Clustering of graph labels.
@@ -395,7 +421,7 @@ class d3graph():
             labx[key]['name'] = key
             labx[key]['color'] = hex_colors[i]
             labx[key]['cluster_label'] = cluster_labels.get(key)
-        
+
         # return
         color = np.array(list(map(lambda x: labx.get(x)['color'], node_names)))
         cluster_label = np.array(list(map(lambda x: labx.get(x)['cluster_label'], node_names)))
@@ -633,6 +659,9 @@ def json_create(G):
         links[i]['target'] = int(target[i])
         links[i]['source_label'] = edges[i][0]
         links[i]['target_label'] = edges[i][1]
+        links[i]['marker_start'] = links[i]['marker_start']
+        links[i]['marker_end'] = links[i]['marker_end']
+        links[i]['marker_color'] = links[i]['marker_color']
         links_new.append(links[i])
     data['links']=links_new
 
@@ -641,7 +670,7 @@ def json_create(G):
     for i, node in enumerate(nodes):
         nodes[i]['node_name'] = nodes[i].pop('label')
         # nodes[i]['node_label'] = nodes[i].pop('label')
-        nodes[i]['node_hover'] = nodes[i].pop('hover')
+        nodes[i]['node_tooltip'] = nodes[i].pop('tooltip')
         nodes[i]['node_color'] = nodes[i].pop('color')
         nodes[i]['node_size'] = nodes[i].pop('size')
         nodes[i]['node_size_edge'] = nodes[i].pop('edge_size')
@@ -654,7 +683,7 @@ def json_create(G):
 
 
 # %%  Convert adjacency matrix to vector
-def adjmat2dict(adjmat, min_weight=0, minmax=[0.5, 15], scaler='zscore'):
+def adjmat2dict(adjmat, min_weight=0, minmax=[0.5, 15], scaler='zscore', marker_start=None, marker_end='arrow', marker_color='#808080'):
     """Convert adjacency matrix into vector with source and target.
 
     Parameters
@@ -671,9 +700,12 @@ def adjmat2dict(adjmat, min_weight=0, minmax=[0.5, 15], scaler='zscore'):
     -------
     edge_properties: dict
         key: (source, target)
-            'weight': weight of the edge
-            'weight_scaled': scaled weight of the edge
-            'color': color of the edge
+            'weight': weight of the edge.
+            'weight_scaled': scaled weight of the edge.
+            'color': color of the edge.
+            'marker_start': '', 'circle', 'square', 'arrow', 'stub'
+            'marker_end': '', 'circle', 'square', 'arrow', 'stub'
+            'marker_color': hex color of the marker.
 
     """
     # Convert adjacency matrix into vector
@@ -690,17 +722,24 @@ def adjmat2dict(adjmat, min_weight=0, minmax=[0.5, 15], scaler='zscore'):
     df = df.loc[Iloc, :]
     df.reset_index(drop=True, inplace=True)
 
-    # Scale the weights for visualization purposes
+    # Scale the weights for visualization purposesdf
     if len(np.unique(df['weight'].values.reshape(-1, 1)))>2:
         df['weight_scaled'] = _normalize_size(df['weight'].values.reshape(-1, 1), minmax[0], minmax[1], scaler=scaler)
     else:
         df['weight_scaled'] = np.ones(df.shape[0]) * 1
 
+    # Set marker start-end
+    if marker_start is None: marker_start=''
+    if marker_end is None: marker_end=''
+    df['marker_start']=marker_start
+    df['marker_end']=marker_end
+    df['marker_color']=marker_color
+
     # Creation dictionary
     source_target = list(zip(df['source'], df['target']))
     dict_edges = {}
     for i, edge in enumerate(source_target):
-        dict_edges[edge] = {'weight': df['weight'].iloc[i], 'weight_scaled': df['weight_scaled'].iloc[i], 'color': '#808080'}
+        dict_edges[edge] = {'weight': df['weight'].iloc[i], 'weight_scaled': df['weight_scaled'].iloc[i], 'color': '#808080', 'marker_start': df['marker_start'].iloc[i], 'marker_end': df['marker_end'].iloc[i], 'marker_color': df['marker_color'].iloc[i]}
 
     # Return
     return(dict_edges)
@@ -729,7 +768,7 @@ def edges2G(edge_properties, G=None):
     edges = [*edge_properties]
     # Create edges in graph
     for edge in edges:
-        G.add_edge(edge[0], edge[1], weight_scaled=np.abs(edge_properties[edge]['weight_scaled']), weight=np.abs(edge_properties[edge]['weight']), color=edge_properties[edge]['color'])
+        G.add_edge(edge[0], edge[1], marker_color=edge_properties[edge]['marker_color'], marker_start=edge_properties[edge]['marker_start'], marker_end=edge_properties[edge]['marker_end'], weight_scaled=np.abs(edge_properties[edge]['weight_scaled']), weight=np.abs(edge_properties[edge]['weight']), color=edge_properties[edge]['color'])
     # Return
     return(G)
 
@@ -802,7 +841,7 @@ def _normalize_size(getsizes, minscale=0.5, maxscale=4, scaler='zscore'):
     # Min-Max Scaling is too sensitive to outlier observations and generates problems unseen, out-of-scale datapoints.
     if scaler=='zscore' and len(np.unique(getsizes))>3:
         getsizes = (getsizes.flatten() - np.mean(getsizes)) / np.std(getsizes)
-        getsizes = getsizes + (minscale-np.min(getsizes))
+        getsizes = getsizes + (minscale - np.min(getsizes))
     elif scaler=='minmax':
         getsizes = MinMaxScaler(feature_range=(minscale, maxscale)).fit_transform(getsizes).flatten()
     else:
@@ -884,7 +923,7 @@ def remove_special_chars(adjmat):
     adjmat : pd.DataFrame()
 
     """
-    logger.debug('Removing special chars and replacing with "_"')
+    logger.info('Remove special characters and spaces from node names. Replace with "_".')
     adjmat.columns = list(map(lambda x: unicodedata.normalize('NFD', x).encode('ascii', 'ignore').decode("utf-8").replace(' ', '_'), adjmat.columns.values.astype(str)))
     adjmat.index = list(map(lambda x: unicodedata.normalize('NFD', x).encode('ascii', 'ignore').decode("utf-8").replace(' ', '_'), adjmat.index.values.astype(str)))
     return adjmat
