@@ -2,8 +2,88 @@
 import networkx as nx
 import pandas as pd
 import numpy as np
+from d3graph import d3graph, adjmat2vec
+
+# %% small example
 from d3graph import d3graph
 
+# Initialize
+d3 = d3graph()
+# Load example
+adjmat = d3.import_example('bigbang')
+# Process adjmat
+d3.graph(adjmat)
+d3.set_node_properties(color=adjmat.columns.values, size=[10, 20, 10, 10, 15, 10, 5])
+
+
+d3.set_edge_properties(directed=True, marker_end='square', marker_color='#000000')
+d3.show(filepath='c:\\temp\\network1.html')
+
+
+
+d3.set_edge_properties(directed=True, marker_end='', marker_color='#000000')
+d3.edge_properties['Penny', 'Leonard']['marker_end']='arrow'
+d3.edge_properties['Sheldon', 'Howard']['marker_end']='stub'
+d3.edge_properties['Sheldon', 'Leonard']['marker_end']='circle'
+d3.edge_properties['Rajesh', 'Penny']['marker_end']='square'
+d3.edge_properties['Penny', 'Leonard']['marker_color']='#ff0000'
+d3.show(filepath='c:\\temp\\network1.html')
+
+d3.set_node_properties(color=adjmat.columns.values, size=[10, 20, 10, 10, 15, 10, 5])
+
+d3.node_properties['Penny']['tooltip']='test\ntest2'
+d3.show(filepath='c:\\temp\\network1.html')
+
+
+# %% Issue marker edges
+# http://bl.ocks.org/dustinlarimer/5888271
+
+from d3graph import d3graph
+size = [10, 20, 10, 10, 15, 10, 5]
+
+# Initialize
+d3 = d3graph()
+# Load example
+adjmat = d3.import_example('bigbang')
+# Process adjmat
+d3.graph(adjmat)
+d3.set_edge_properties(directed=True)
+# Show
+# d3.show(filepath='c:\\temp\\network.html')
+
+d3.set_node_properties(color=adjmat.columns.values)
+d3.show(filepath='c:\\temp\\network.html')
+
+d3.set_node_properties(color=adjmat.columns.values, size=size)
+d3.show()
+
+d3.set_node_properties(color=adjmat.columns.values, size=size, edge_size=size[::-1])
+d3.show()
+
+d3.set_node_properties(color=adjmat.columns.values, size=size, edge_size=size[::-1], edge_color='#00FFFF')
+d3.show()
+
+d3.set_edge_properties(directed=True)
+d3.set_node_properties(color=adjmat.columns.values, size=size, edge_size=size, edge_color='#000FFF', cmap='Set1')
+d3.set_node_properties(color='cluster', size=size, edge_size=size, edge_color='#000FFF', cmap='Set2')
+d3.set_node_properties(color='cluster', size=size, edge_size=size, edge_color='cluster', cmap='Set2')
+d3.show()
+
+d3.edge_properties['Penny', 'Leonard']['color']='#ff0000'
+d3.edge_properties['Bernadette', 'Howard']['color']='#ff0000'
+d3.show(filepath='c:\\temp\\network.html')
+
+color, cluster_label, node_names = d3.get_cluster_color()
+
+# %%
+from d3graph import d3graph, adjmat2vec
+size=(100, 100)
+adjmat = pd.DataFrame(np.random.randint(0, 10, size=size))
+# Initialize
+d3 = d3graph(collision=0.5, charge=10350)
+d3.graph(adjmat)
+d3.set_node_properties(color='cluster')
+d3.show(figsize=(1500, 1500))
 
 # %% default example
 from d3graph import d3graph
@@ -60,42 +140,6 @@ d3.graph(adjmat)
 d3.set_node_properties(color=df['label'].values)
 d3.show()
 
-# %% Issue edge colors
-from d3graph import d3graph
-size = [10, 20, 10, 10, 15, 10, 5]
-
-# Initialize
-d3 = d3graph()
-# Load example
-adjmat = d3.import_example('bigbang')
-# Process adjmat
-d3.graph(adjmat)
-# Show
-# d3.show()
-
-# d3.set_node_properties(color=adjmat.columns.values)
-# d3.show()
-
-# d3.set_node_properties(color=adjmat.columns.values, size=size)
-# d3.show()
-
-# d3.set_node_properties(color=adjmat.columns.values, size=size, edge_size=size[::-1])
-# d3.show()
-
-# d3.set_node_properties(color=adjmat.columns.values, size=size, edge_size=size[::-1], edge_color='#00FFFF')
-# d3.show()
-
-# d3.set_edge_properties(directed=True)
-# d3.set_node_properties(color=adjmat.columns.values, size=size, edge_size=size, edge_color='#000FFF', cmap='Set1')
-# d3.set_node_properties(color='cluster', size=size, edge_size=size, edge_color='#000FFF', cmap='Set2')
-d3.set_node_properties(color='cluster', size=size, edge_size=size, edge_color='cluster', cmap='Set2')
-# d3.show()
-
-d3.edge_properties['Penny', 'Leonard']['color']='#ff0000'
-d3.edge_properties['Bernadette', 'Howard']['color']='#0000ff'
-d3.show()
-
-color, cluster_label, node_names = d3.get_cluster_color()
 
 # %%
 from d3graph import d3graph
@@ -110,7 +154,7 @@ d3.graph(adjmat)
 # d3.set_node_properties(color=adjmat.columns.values)
 # d3.show()
 
-d3.set_node_properties(color=adjmat.columns.values, hover=['This is text for node A','Text for node B','\nMore text can be added on a new line\n with the slash n','','','',''])
+d3.set_node_properties(color=adjmat.columns.values, tooltip=['This is text for node A','Text for node B','\nMore text can be added on a new line\n with the slash n','','','',''])
 d3.show()
 
 # %% Convert source-target to adjmat
@@ -133,11 +177,11 @@ from d3graph import d3graph
 d3 = d3graph()
 adjmat = d3.import_example('bigbang')
 d3.graph(adjmat)
-d3.set_node_properties(color='', label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
-d3.set_node_properties(color=[], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
-d3.set_node_properties(color=['#000000', '#000000', '#000000', '#000', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
-d3.set_node_properties(color=['#000000', '#000000', '#000000', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
-d3.set_node_properties(color=['#000000', '#000000', '#00', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color='', label=adjmat.columns.values+' are the names', tooltip=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=[], label=adjmat.columns.values+' are the names', tooltip=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=['#000000', '#000000', '#000000', '#000', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', tooltip=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=['#000000', '#000000', '#000000', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', tooltip=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=['#000000', '#000000', '#00', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', tooltip=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
 d3.show()
 
 # %%
@@ -146,7 +190,7 @@ from d3graph import d3graph
 d3 = d3graph()
 adjmat = d3.import_example('bigbang')
 d3.graph(adjmat)
-d3.set_node_properties(label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(label=adjmat.columns.values+' are the names', tooltip=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
 d3.show()
 
 
@@ -186,7 +230,7 @@ d3.show()
 d3.set_node_properties(color='cluster', cmap='Set1')
 d3.show()
 
-d3.set_node_properties(label=df['label'].values, hover=adjmat.columns.values, color=df['label'].values, cmap='Set1')
+d3.set_node_properties(label=df['label'].values, tooltip=adjmat.columns.values, color=df['label'].values, cmap='Set1')
 d3.show()
 
 
@@ -263,10 +307,10 @@ d3.show()
 d3.set_node_properties(color=label, size=node_size, label=label)
 d3.show()
 
-d3.set_node_properties(color=label, size=node_size, label=label, hover=label+' hover text')
+d3.set_node_properties(color=label, size=node_size, label=label, tooltip=label+' hover text')
 d3.show()
 
-d3.set_node_properties(color=label, size=node_size, label=label, edge_color='cluster', edge_size=5, hover=label+' hover text')
+d3.set_node_properties(color=label, size=node_size, label=label, edge_color='cluster', edge_size=5, tooltip=label+' hover text')
 d3.show()
 
 d3.set_edge_properties(edge_distance=100)
